import React, { useEffect, useState } from "react";
import DataGrid from "react-data-grid";
import { Box, Typography, Snackbar, Alert, CircularProgress } from "@mui/material";
import { LogisticsService } from "../../../frontend/openapi";

interface Dewar {
    id: string;
    dewar_name: string;
    status: string;
    location: string;
    timestamp: string; // You can change this type based on your API response
}

const DewarStatusTab: React.FC = () => {
    const [dewars, setDewars] = useState<Dewar[]>([]);
    const [loading, setLoading] = useState<boolean>(false);
    const [error, setError] = useState<string | null>(null);

    const columns = [
        { key: "dewar_name", name: "Dewar Name", resizable: true },
        {
            key: "status",
            name: "Status",
            editable: true,
            resizable: true,
            editor: (props: { row: any; column: any; onRowChange: any }) => {
                return (
                    <input
                        type="text"
                        value={props.row[props.column.key]}
                        onChange={(e) => props.onRowChange({ ...props.row, [props.column.key]: e.target.value })}
                        style={{
                            border: "none",
                            outline: "none",
                            padding: "4px",
                        }}
                    />
                );
            },
        },
        { key: "location", name: "Location", resizable: true },
        { key: "timestamp", name: "Last Updated", resizable: true },
    ];

    // Fetch dewars when component mounts
    useEffect(() => {
        fetchDewarData();
    }, []);

    const fetchDewarData = async () => {
        setLoading(true);
        try {
            const dewarData = await LogisticsService.getAllDewarsLogisticsDewarsGet(); // Use your real API call
            setDewars(dewarData);
        } catch (e) {
            setError("Failed to fetch dewar data");
        } finally {
            setLoading(false);
        }
    };

    const onRowsChange = async (updatedRow: Dewar[]) => {
        setDewars(updatedRow);
        try {
            const updatedDewar = updatedRow[updatedRow.length - 1]; // Get the last edited row
            await LogisticsService.updateDewarStatus({ ...updatedDewar }); // Mock API update
        } catch (err) {
            setError("Error updating dewar");
        }
    };

    return (
        <Box>
            <Typography variant="h5" gutterBottom>
                Dewar Status
            </Typography>
            {loading ? (
                <CircularProgress />
            ) : error ? (
                <Snackbar open autoHideDuration={6000} onClose={() => setError(null)}>
                    <Alert severity="error" onClose={() => setError(null)}>
                        {error}
                    </Alert>
                </Snackbar>
            ) : (
                <DataGrid
                    columns={columns}
                    rows={dewars}
                    onRowsChange={onRowsChange}
                    style={{ height: 600, width: "100%" }}
                />
            )}
        </Box>
    );
};

export default DewarStatusTab;